@@ -178,6 +178,9 @@ class AndroidResourceUnit(base.TranslationUnit):
     def istranslatable(self):
         return bool(self.getid()) and self.xmlelement.get("translatable") != "false"
 
+    def marktranslatable(self, value: bool) -> None:
+        return self.xmlelement.set("translatable", "true" if value else "false")
+
     def isblank(self):
         return not bool(self.getid())
 
@@ -367,8 +370,10 @@ class AndroidResourceUnit(base.TranslationUnit):
         if len(xmltarget) == 0:
             # There are no html markups, so unescaping it as plain text.
             return self.unescape(xmltarget.text)
+        parser = DecodingXMLParser(
+            etree.tostring(xmltarget, encoding="unicode", with_tail=False)
+        )
 
-        parser = DecodingXMLParser(etree.tostring(xmltarget, encoding="unicode"))
         return parser.parse()
 
     def set_xml_text_plain(self, target, xmltarget):
