@@ -24,6 +24,7 @@ import codecs
 import logging
 import pickle
 from io import BytesIO
+from itertools import starmap
 
 from translate.misc.multistring import multistring
 from translate.storage.placeables import StringElem
@@ -145,7 +146,7 @@ class TranslationUnit:
         return not self.__eq__(other)
 
     def __hash__(self):
-        return None
+        return hash((self.source, self.target, self.getid()))
 
     def __str__(self):
         """Converts to a string representation. Most often overriden by subclasses."""
@@ -407,6 +408,9 @@ class TranslationUnit:
         """
         return bool(self.source)
 
+    def marktranslatable(self, value: bool) -> None:
+        """Marks the unit as translateable or not."""
+
     @staticmethod
     def isfuzzy():
         """Indicates whether this unit is fuzzy."""
@@ -913,6 +917,14 @@ class TranslationStore:
             fileobj = open(filename, "wb")
         self.savefile(fileobj)
 
+    @classmethod
+    def _from_handle(cls, storehandle):
+        storestring = storehandle.read()
+        newstore = cls.parsestring(storestring)
+        newstore.fileobj = storehandle
+        newstore._assignname()
+        return newstore
+
     @classmethod
     def parsefile(cls, storefile):
         """
@@ -920,16 +932,16 @@ class TranslationStore:
         to an object.
         """
         if isinstance(storefile, str):
-            storefile = open(storefile, "rb")
+            with open(storefile, "rb") as storehandle:
+                return cls._from_handle(storehandle)
         mode = getattr(storefile, "mode", "rb")
         # For some reason GzipFile returns 1, so we have to test for that here
         if mode == 1 or "r" in mode:
-            storestring = storefile.read()
+            newstore = cls._from_handle(storefile)
             storefile.close()
-            newstore = cls.parsestring(storestring)
-        else:
-            storestring = ""
-            newstore = cls()
+            return newstore
+
+        newstore = cls()
         newstore.fileobj = storefile
         newstore._assignname()
         return newstore
@@ -960,7 +972,7 @@ class UnitId:
                 return f"{self.INDEX_SEPARATOR}[{key}]"
             raise ValueError(f"Unsupported element: {element}")
 
-        return "".join(fmt(*part) for part in self.parts)
+        return "".join(starmap(fmt, self.parts))
 
     def extend(self, key, value):
         return self.__class__([*self.parts, (key, value)])
